@@ -1,14 +1,15 @@
 ## Google (Images)
-# 
+#
 # @website     https://www.google.com
-# @provide-api yes (https://developers.google.com/web-search/docs/), deprecated!
-# 
+# @provide-api yes (https://developers.google.com/web-search/docs/),
+#              deprecated!
+#
 # @using-api   yes
 # @results     JSON
 # @stable      yes (but deprecated)
 # @parse       url, title, img_src
 
-from urllib import urlencode
+from urllib import urlencode,unquote
 from json import loads
 
 # engine dependent config
@@ -51,7 +52,7 @@ def response(resp):
         results.append({'url': href,
                         'title': title,
                         'content': '',
-                        'img_src': result['url'],
+                        'img_src': unquote(result['url']),
                         'template': 'images.html'})
 
     # return results
