@@ -17,10 +17,6 @@ along with searx. If not, see < http://www.gnu.org/licenses/ >.
 (C) 2013- by Adam Tauber, <asciimoo@gmail.com>
 '''
 
-from gevent import monkey
-monkey.patch_all()
-
-
 if __name__ == '__main__':
     from sys import path
     from os.path import realpath, dirname
@@ -44,6 +40,7 @@ from searx.engines import (
 from searx.utils import (
     UnicodeWriter, highlight_content, html_to_text, get_themes
 )
+from searx.version import VERSION_STRING
 from searx.https_rewrite import https_rules
 from searx.languages import language_codes
 from searx.search import Search
@@ -71,9 +68,9 @@ app.secret_key = settings['server']['secret_key']
 
 babel = Babel(app)
 
-# TODO configurable via settings.yml
-favicons = ['wikipedia', 'youtube', 'vimeo', 'soundcloud',
-            'twitter', 'stackoverflow', 'github']
+#TODO configurable via settings.yml
+favicons = ['wikipedia', 'youtube', 'vimeo', 'dailymotion', 'soundcloud',
+            'twitter', 'stackoverflow', 'github', 'deviantart']
 
 cookie_max_age = 60 * 60 * 24 * 365 * 23  # 23 years
 
@@ -171,6 +168,8 @@ def render(template_name, override_theme=None, **kwargs):
     if 'autocomplete' not in kwargs:
         kwargs['autocomplete'] = autocomplete
 
+    kwargs['searx_version'] = VERSION_STRING
+
     kwargs['method'] = request.cookies.get('method', 'POST')
 
     # override url_for function in templates
@@ -178,6 +177,8 @@ def render(template_name, override_theme=None, **kwargs):
 
     kwargs['theme'] = get_current_theme_name(override=override_theme)
 
+    kwargs['template_name'] = template_name
+
     return render_template(
         '{}/{}'.format(kwargs['theme'], template_name), **kwargs)
 
@@ -293,10 +294,9 @@ def index():
 
         # TODO, check if timezone is calculated right
         if 'publishedDate' in result:
-            if result['publishedDate'].replace(tzinfo=None)\
-               >= datetime.now() - timedelta(days=1):
-                timedifference = datetime.now() - result['publishedDate']\
-                    .replace(tzinfo=None)
+            result['pubdate'] = result['publishedDate'].strftime('%Y-%m-%d %H:%M:%S%z')
+            if result['publishedDate'].replace(tzinfo=None) >= datetime.now() - timedelta(days=1):
+                timedifference = datetime.now() - result['publishedDate'].replace(tzinfo=None)
                 minutes = int((timedifference.seconds / 60) % 60)
                 hours = int(timedifference.seconds / 60 / 60)
                 if hours == 0:
@@ -304,8 +304,6 @@ def index():
                 else:
                     result['publishedDate'] = gettext(u'{hours} hour(s), {minutes} minute(s) ago').format(hours=hours, minutes=minutes)  # noqa
             else:
-                result['pubdate'] = result['publishedDate']\
-                    .strftime('%a, %d %b %Y %H:%M:%S %z')
                 result['publishedDate'] = format_date(result['publishedDate'])
 
     if search.request_data.get('format') == 'json':
